@@ -168,6 +168,8 @@
 #' If \code{anchor[1]=3}: anchor the non-radiogenic component to the
 #' Stacey-Kramers mantle evolution model.
 #'
+#' @param cutoff.disc discordance cutoff filter. This is an object of
+#'     class \code{\link{discfilter}}.
 #' @param ticks either a scalar indicating the desired number of age
 #'     ticks to be placed along the concordia line, OR a vector of
 #'     tick ages.
@@ -275,7 +277,8 @@ concordia <- function(x=NULL,tlim=NULL,type=1,
                       ellipse.stroke='black',concordia.col='darksalmon',
                       exterr=FALSE,show.age=0,oerr=3,
                       sigdig=2,common.Pb=0,ticks=5,anchor=0,
-                      hide=NULL,omit=NULL,omit.fill=NA,omit.stroke='grey',...){
+                      cutoff.disc=discfilter(),hide=NULL,
+                      omit=NULL,omit.fill=NA,omit.stroke='grey',...){
     concordia_helper(x=x,tlim=tlim,type=type,show.numbers=show.numbers,
                      levels=levels,clabel=clabel,
                      ellipse.fill=ellipse.fill,
@@ -283,7 +286,8 @@ concordia <- function(x=NULL,tlim=NULL,type=1,
                      concordia.col=concordia.col,exterr=exterr,
                      show.age=show.age,oerr=oerr,sigdig=sigdig,
                      common.Pb=common.Pb,ticks=ticks,anchor=anchor,
-                     hide=hide,omit=omit,omit.fill=omit.fill,
+                     cutoff.disc=cutoff.disc,hide=hide,
+                     omit=omit,omit.fill=omit.fill,
                      omit.stroke=omit.stroke,...)
 }
 
@@ -295,30 +299,42 @@ concordia_helper <- function(x=NULL,tlim=NULL,type=1,
                              ellipse.stroke='black',concordia.col='darksalmon',
                              exterr=FALSE,show.age=0,oerr=3,y0option=1,
                              sigdig=2,common.Pb=0,ticks=5,anchor=0,
-                             hide=NULL,omit=NULL,omit.fill=NA,
-                             omit.stroke='grey',box=TRUE,...){
+                             cutoff.disc=discfilter(),hide=NULL,
+                             omit=NULL,omit.fill=NA,omit.stroke='grey',
+                             box=TRUE,...){
     if (is.null(x)){
         emptyconcordia(tlim=tlim,oerr=oerr,type=type,exterr=exterr,
                        concordia.col=concordia.col,ticks=ticks,...)
         return(invisible(NULL))
     }
+    if (common.Pb>0){
+        X <- Pb0corr(x,option=common.Pb,omit4c=unique(c(hide,omit)))
+    } else {
+        X <- x
+    }
+    if (cutoff.disc$before){
+        discordant <- is.discordant(x=x,cutoff.disc=cutoff.disc)
+    } else {
+        discordant <- is.discordant(x=x,xd=X,cutoff.disc=cutoff.disc)
+    }
+    omit <- unique(c(omit,discordant))
     ns <- length(x)
     plotit <- (1:ns)%ni%hide
     calcit <- (1:ns)%ni%c(hide,omit)
-    x2calc <- subset(x,subset=calcit)
-    if (common.Pb<1) X <- x
-    else X <- Pb0corr(x,option=common.Pb,omit4c=unique(c(hide,omit)))
     X2plot <- subset(X,subset=plotit)
+    if (show.age>1) {
+        X2calc <- subset(x,subset=calcit)
+    } else {
+        X2calc <- subset(X,subset=calcit)
+    }
     fit <- NULL
-    if (show.age>1) X2calc <- x2calc
-    else X2calc <- subset(X,subset=calcit)
     if (show.age==1){
         fit <- concordia_age(X2calc,type=type,exterr=exterr)
     } else if (show.age>1){
         lfit <- ludwig(X2calc,exterr=exterr,model=(show.age-1),anchor=anchor)
         fit <- discordia(X2calc,fit=lfit,wetherill=(type==1))
     }
-    fit$n <- length(x2calc)
+    fit$n <- length(X2calc)
     lims <- prepare_concordia_line(x=X2plot,tlim=tlim,type=type,...)
     if (show.age>1){
         discordia_line(fit,wetherill=(type==1),d=X2plot$d,oerr=oerr)
@@ -671,30 +687,18 @@ concordia_age <- function(x,i=NULL,type=1,exterr=FALSE,...){
 }
 # cc is assumed to follow a wetherill or cottle format
 concordia_age_helper <- function(cc,d=diseq(),type=1,exterr=FALSE,...){
-    v <- eigen(cc$cov)$vectors[,1]
-    slope <- v[2]/v[1]
     lower <- upper <- init <- vector()
-    U85 <- iratio('U238U235')[1]
-    l8 <- lambda('U238')[1]
     tmin <- 0
-    tmax <- ifelse(measured_disequilibrium(d),meas_diseq_maxt(d),10000)
     if (type==1){
-        l5 <- lambda('U235')[1]
-        if (slope>0){
-            tmid <- log(slope*l5/l8)/(l8-l5) # tangential to error ellipse
-        } else {
-            tmid <- log(-l8/(l5*slope))/(l5-l8) # normal to error ellipse
-        }
+        tmid1 <- get_Pb207U235_age(cc$x['Pb207U235'],d=d)[1]
+        tmid2 <- get_Pb206U238_age(cc$x['Pb206U238'],d=d)[1]
     } else if (type==3){
-        l2 <- lambda('Th232')[1]
-        if (slope>0){
-            tmid <- log(slope*l8/l2)/(l2-l8) # tangential to error ellipse
-        } else {
-            tmid <- log(-l2/(l8*slope))/(l8-l2) # normal to error ellipse
-        }
+        tmid1 <- get_Pb206U238_age(cc$x['Pb206U238'],d=d)[1]
+        tmid2 <- get_Pb208Th232_age(cc$x['Pb208Th232'])[1]
     } else {
         stop('concordia_age_helper is not available for concordia type ', type)
     }
+    tmax <- ifelse(measured_disequilibrium(d),meas_diseq_maxt(d),10000)
     if (d$U48$option>0){
         if (d$U48$option==2 && (is.null(d$U48$sx) || d$U48$sx<=0)){
             stop('Zero uncertainty of measured 234/238 activity ratio')
@@ -723,22 +727,19 @@ concordia_age_helper <- function(cc,d=diseq(),type=1,exterr=FALSE,...){
         lower['PaUi'] <- 0
         upper['PaUi'] <- 20
     }
-    lower['t'] <- tmin
-    upper['t'] <- tmid
-    init['t'] <- (lower['t'] + upper['t'])/2
-    fit1 <- stats::optim(init,LL_concordia_age,method='L-BFGS-B',
-                         lower=lower,upper=upper,exterr=exterr,
-                         cc=cc,type=type,d=d,hessian=TRUE)
-    lower['t'] <- tmid
-    upper['t'] <- tmax
-    init['t'] <- (lower['t'] + upper['t'])/2
-    fit2 <- stats::optim(init,LL_concordia_age,method='L-BFGS-B',
-                         lower=lower,upper=upper,exterr=exterr,
-                         cc=cc,type=type,d=d,hessian=TRUE)
-    o1 <- fit1$value
-    o2 <- fit2$value
-    if (is.finite(o1)) out <- fit1
-    if (is.finite(o2) && o2<o1) out <- fit2
+    tt <- sort(c(tmin,tmid1,tmid2,tmax))
+    out <- list(value=Inf)
+    for (i in 2:length(tt)){
+        lower['t'] <- tt[i-1]
+        upper['t'] <- tt[i]
+        init['t'] <- (lower['t'] + upper['t'])/2
+        fit <- stats::optim(init,LL_concordia_age,method='L-BFGS-B',
+                            lower=lower,upper=upper,exterr=exterr,
+                            cc=cc,type=type,d=d,hessian=TRUE)
+        if (is.finite(fit$value) && fit$value<out$value){
+            out <- fit
+        }
+    }
     out$cov <- inverthess(out$hessian)
     out
 }
